<?php
/**
* Return Twitter Data
*
* Functions to return Twitter data to user
*
* @package	Artiss-Twitter-Data
*/

/**
* Twitter Shortcode
*
* Shortcode to return a single piece of Twitter profile data
*
* @since		1.0
*
* @uses 	get_twitter_profile		Return profile data
*
* @param	string  $paras          Parameters
* @return	string					User data
*/

function atd_twitter_sc( $paras ) {
    extract( shortcode_atts( array( 'user' => '', 'data' => '', 'cache' => '0.5' ), $paras ) );
    return get_twitter_profile( 'user=' . $user . '&data=' . $data . '&cache=' . $cache );
}
add_shortcode( 'twitter', 'atd_twitter_sc' );

/**
* Return Twitter Data
*
* Get user data from Twitter and return the requested data
*
* @since	1.0
*
* @uses 	atd_get_parameter       Extract parameter
* @uses     atd_report_error        Show an error message
* @uses     atd_get_data_parameters Extract data parameters
* @uses     atd_get_file            Fetch a file
* @uses     atd_extract_xml         Extract data from XML
* @uses     atd_relative_time       Return the relative time
*
* @param	string  $paras          Parameters
* @return	string					User data (array or single string)
*/

function get_twitter_profile( $paras ) {

    $error = false;

    // Extract the parameters

    $username = atd_get_parameter( $paras, 'user');
    if ( $username == '' ) { $error = atd_report_error( 'No username was specified', 'Artiss Twitter Data' ); }
    $data = atd_get_parameter( $paras, 'data' );
    if ( $data == '' ) { $error = atd_report_error( 'Data request not specified', 'Artiss Twitter Data' ); }
    $data_requests = atd_get_data_parameters( $data );
    $cache_time = strtolower( atd_get_parameter( $paras, 'cache' ) );
    if ( $cache_time == '' ) { $cache = 0.5; }
    $nofollow = strtolower( atd_get_parameter( $paras, 'nofollow' ) );
    if ( $nofollow == 'yes') { $nofollow = ' rel="nofollow"'; } else { $nofollow = ''; }
    $target = strtolower( atd_get_parameter( $paras, 'target' ) );
    if ( $target == '' ) { $target = '_blank';}

    // Get the appropriate XML file - use caching, if required

    if ( !$error ) {

        $xmlfile = 'http://twitter.com/users/show/' . $username . '.xml';

        if ( $cache_time == 'no' ) {
            $return_data = false;
        } else {
            $cache_key = 'atd_user_' . md5( $paras );
            $return_data = get_transient( $cache_key );
        }

        if ( !$return_data ) {

            $file_return = atd_get_file( $xmlfile );
            $array = $file_return[ 'file' ];

            // Loop through all the data requests
            $loop = 1;
            while ( $loop <= $data_requests[ 0 ] ) {
                $data = $data_requests[ $loop ];
                $tag = '';

                // Convert the requested data to the XML field name

                if ( $data == 'name' ) { $tag = $data; }
                if ( $data == 'location' ) { $tag = $data; }
                if ( $data == 'description' ) { $tag = $data; }
                if ( $data == 'image' ) { $tag = 'profile_image_url'; }
                if ( $data == 'image73' ) { $tag = 'profile_image_url'; }
                if ( ( $data == 'followers' ) or ( $data == 'followers-sep' ) ) { $tag = 'followers_count'; }
                if ( ( $data == 'following' ) or ( $data == 'following-sep' ) ) { $tag = 'friends_count'; }
                if ( $data == 'status' ) { $tag = 'text'; }
                if ( $data == 'source' ) { $tag = $data; }
                if ( $data == 'url' ) { $tag = $data; }
                if ( $data == 'created' ) { $tag = 'created_at'; }
                if ( $data == 'relative' ) { $tag = 'created_at'; }
                if ( $data == 'id' ) { $tag = $data; }

                if ( $tag == '' ) {
                    atd_report_error( 'Invalid data item - ' . $data, 'Artiss Twitter Data' );
                    $output_data[ $data ] = '';
                } else {

                    // Now get the requested Twitter data

                    if ( ( $tag == 'created_at' ) or ( $tag == 'id' ) ) {
                        $source_array = atd_extract_xml( $array, 'status' );
                        $output_data[ $data ] = atd_extract_xml( $source_array, $tag );
                        if ( $data == 'relative' ) { $output_data[ $data ] = atd_relative_time( $output_data[ $data ] ); }
                        if ( $data == 'id' ) { $output_data[ $data ] = 'http://twitter.com/' . $username . '/statuses/' . $output_data[ $data ]; }
                    } else {
                       $output_data[ $data ] = atd_extract_xml( $array, $tag );
                    }

                    if ( $tag == 'source' ) { $output_data[ $data ] = html_entity_decode( $output_data[ $data ], ENT_QUOTES ); }
                    if ( $tag == 'text' ) { $output_data[ $data ] = ereg_replace( "[[:alpha:]]+://[^<>[:space:]]+[[:alnum:]/]", "<a href=\"\\0\" target=\"" . $target . "\"" . $nofollow . ">\\0</a>", htmlentities( $output_data[ $data ] ) ); }
                    if ( $data == 'image73' ) { $output_data[ $data ] = str_replace( '_normal.', '_bigger.', $output_data[ $data ] ); }
                    if ( ( $data == 'followers-sep' ) or ( $data == 'following-sep' ) ) { $output_data[ $data ] = number_format( $output_data[ $data ] ); }

                    if ( $output_data[ $data ] == '' ) {
                        $output_data[ $data ] = false;
                    } else {
                        $output_data[ $data ] = atd_decode( $output_data[ $data ] );
                    }
                    $single_out = $output_data[ $data ];
                }
                $loop++;
            }

            if ( $data_requests[ 0 ] == 1 ) {
                $return_data = $single_out;
            } else {
                $return_data = $output_data;
            }

            if ( $cache_time != 'no' ) { set_transient( $cache_key, $return_data, 3600 * $cache_time ); }
        }

    } else {
        $return_data = false;
    }

    return $return_data;
}

/**
* Return URL references
*
* Use TweetMeMe to return the number of times that URL has been referenced
*
* @since	1.1
*
* @uses 	atd_get_file            Fetch a file
* @uses     atd_extract_xml         Extract data from XML
*
* @param    string  $url            URL to check for
* @param	string  $paras          Parameters
* @return	string					Number of times URL has been referenced
*/

function get_twitter_count( $url, $paras = '' ) {

    $cache_time = strtolower( atd_get_parameter( $paras, 'cache' ) );
    if ( $cache_time == '' ) { $cache = 0.5; }

    $xmlfile = 'http://api.tweetmeme.com/url_info?url=' . $url;

    if ( $cache_time == 'no' ) {
        $count = false;
    } else {
        $cache_key = 'atd_count_' . md5( $xmlfile . $paras );
        $count = get_transient( $cache_key );
    }

    if ( !$count ) {
        $array = atd_get_file( $xmlfile );
        $count = atd_extract_xml( $array, 'url_count' );
        if ( $cache_time != 'no' ) { set_transient( $cache_key, $count, 3600 * $cache_time ); }
    }

    return $count;
}
?>